# kdecole-py
Transcription de la librairie NodeJS [kdecole-api](https://github.com/maelgangloff/kdecole-api) en Python.  
Pour plus d'information, veuillez vous reporter au README de ce projet (https://github.com/maelgangloff/kdecole-api)
